﻿import com.robertpenner.utils.Degree;

/**
* The Polar class converts between polar and cartesian coordinate systems.
* 
* @author Robert Penner (AS 1.0)
* © 2002 Robert Penner
* http://www.robertpenner.com
* 
* @author Mark Walters (AS 2.0)
* © 2006 DigitalFlipbook
* http://www.digitalflipbook.com
* 
* @version	1.0
* 
* @since	ActionScript 2.0; Flash Player 6
*/
class com.robertpenner.utils.Polar {
	
	/*
	* *********************************************************
	* CONSTRUCTOR
	* *********************************************************
	*
	*/
	function Polar () {
	}
	
	
	/*
	* *********************************************************
	* PUBLIC METHODS
	* *********************************************************
	* 
	*/
	
	/**
	* Converts a point from cartesian to polar coordinates.
	* 
	* @param	x	The x value of the point.
	* @param	y	The y value of the point.
	* @return	Returns the radius and theta of the point in a point object.
	* 
	* @usage
	* <pre><code>
	* var polarPoint:Object = Polar.cartesianToPolar (3, 4);
	* trace (polarPoint.r);
	* trace (polarPoint.t);
	* </code></pre>
	*/
	public static function cartesianToPolar (x:Number, y:Number):Object {
		var radius:Number = Math.sqrt (x*x + y*y);
		var theta:Number = Degree.atan2D (y, x);
		return {r:radius, t:theta};
	}
	
	/**
	* Converts a point from cartesian to polar coordinates.
	* 
	* @param	p	The point, with x and y properties, to convert.
	* @return	Returns the radius and theta of the point in a point object.
	* 
	* @usage
	* <pre><code>
	* var cartesianPoint:Object = {x:3, y:4};
	* var polarPoint:Object = Polar.cartesianToPolarPts (cartesianPoint);
	* trace (polarPoint.r);
	* trace (polarPoint.t);
	* </code></pre>
	*/
	public static function cartesianToPolarPts (p:Object):Object {
		var radius:Number = Math.sqrt (p.x*p.x + p.y*p.y);
		var theta:Number = Degree.atan2D (p.y, p.x);
		return {r:radius, t:theta};
	}
	
	/**
	* Converts a point from polar to cartesian coordinates.
	* 
	* @param	r	The radius of the point.
	* @param	t	The theta of the point.
	* @return	Returns the x and y values of the point in a point object.
	* 
	* @usage
	* <pre><code>
	* var cartesianPoint:Object = Polar.polarToCartesian (5, 90);
	* trace (cartesianPoint.x);
	* trace (cartesianPoint.y);
	* </code></pre>
	*/
	public static function polarToCartesian (r:Number, t:Number):Object {
		var x:Number = r * Degree.cosD (t);
		var y:Number = r * Degree.sinD (t);
		return {x:x, y:y};
	}
	
	/**
	* Converts a point from polar to cartesian coordinates.
	* 
	* @param	p	The point, with r and t properties, to convert.
	* @return	Returns the x and y values of the point in a point object.
	* 
	* @usage
	* <pre><code>
	* var polarPoint:Object = {r:5, t:90};
	* var cartesianPoint:Object = Polar.polarToCartesianPts (polarPoint);
	* trace (cartesianPoint.x);
	* trace (cartesianPoint.y);
	* </code></pre>
	*/
	public static function polarToCartesianPts (p:Object):Object {
		var x:Number = p.r * Degree.cosD (p.t);
		var y:Number = p.r * Degree.sinD (p.t);
		return {x:x, y:y};
	}
}
